@@ -42,7 +42,7 @@ class Storage:
     differet RNA binding proteins (RBPs) can bind. Thus each BindingSite
     represents an RBP molecule, within a Storage.
 
-    This class stores data about a lncRNA and RBPs that might bind to it, as
+    This class stores data about an RNA and RBPs that might bind to it, as
     well as the sites at which they bind (using dictionaries that store
     BindingSites values)
     """
@@ -56,7 +56,7 @@ class Storage:
         # just a nested dictionary) is created and stored here. For any two
         # RBPs x and y, self.corr_table[x][y] gives the correlation between
         # x and y's binding sites (when y is "thrown" at x)
-        self.corr_table = -1
+        # self.corr_table = -1
 
         # The same correlation table aforementioned, but [x][y] and [y][x]
         # give the same result, which is the f-score (2pq/(p+q) where p and
@@ -65,11 +65,6 @@ class Storage:
         # a one-way street
         self.corr_table_f_measure = -1
 
-        # Stores a list of tuples sorted by the distance scores. The tuples
-        # are of the form (x,y,score) where x and y are RBP gene names. Note
-        # that the scores here are actually the f-scores!
-        self.corr_sorted = -1
-
         # When the analysis was done, what was the base pair stringency used?
         self.corr_bp_threshold = -1
 
@@ -173,9 +168,7 @@ class Storage:
         Resets correlation data stored internally.
         In case new data is added, it's a good idea to reset correlation data
         """
-        self.corr_table = -1
         self.corr_table_f_measure = -1
-        self.corr_sorted = -1
 
     def __setitem__(self, item, value):
         # Discourage this use mostly, but if the types are right why not
@@ -199,16 +192,14 @@ class Storage:
         """
 
         summary_info = []
-        for rbp in self._rbps:
-            summary_info.append((rbp, len(self._rbps[rbp])))
+        for rbp, sites in self._rbps.items():
+            summary_info.append((rbp, len(sites)))
 
         return len(self._rbps), sum([k for (a, k) in summary_info])
 
     def self_analysis(
         self,
         bp_threshold=30,
-        display_threshold=0.8,
-        verbose=False,
         progress_feedback=True,
     ):
         """
@@ -224,8 +215,6 @@ class Storage:
         :param display_threshold: Threshold correlation value below which the
                                   pairwise RBP correlations are not shown.
                                   (Default value = 0.8)
-        :param verbose: specifies level of detail in output
-                        (Default value = False)
         :param progress_feedback: specifies whether the progress of analysis is
                                   printed continuously as the correlations are
                                   calculated
@@ -234,7 +223,10 @@ class Storage:
         """
 
         # If analysis hasn't happened yet or different stringency is being used:
-        if self.corr_table == -1 or self.corr_bp_threshold != bp_threshold:
+        if (
+            self.corr_table_f_measure == -1
+            or self.corr_bp_threshold != bp_threshold
+        ):
             corr_table = {}  # Stores the correlation table (nested dictionary)
             prev_num = 0
             num_j = 0
@@ -281,81 +273,15 @@ class Storage:
 
                     tuple_list.append((i, j, corr_table_f_score[i][j]))
 
-            sorted_tuple_list = sorted(tuple_list, key=thirdItem, reverse=True)
-
-            self.corr_table = corr_table
             self.corr_table_f_measure = corr_table_f_score
-            self.corr_sorted = sorted_tuple_list
             self.corr_bp_threshold = bp_threshold
 
-            if verbose:
-                print("Data was saved in storage")
-
-        if verbose:
-            print(
-                "Some of the highest score pairs above threshold"
-                " (0.8 by default):"
-            )
-
-            for output in self.corr_sorted:  # sorted three element tuple list
-                if 1.0 > output[2] > display_threshold:
-                    print(output)
-
-        return (
-            self.corr_table,
-            self.corr_table_f_measure,
-            self.corr_sorted,
-            self.corr_bp_threshold,
-        )
-
-    def lookup(
-        self, first_rbp, second_rbp=-1, display_threshold=-0.1, bp_threshold=30
-    ):
-        """
-        gets the correlation value for a specific RBP and all RBPs or a specific
-        RBP and another one.
-        :param first_rbp: the first RBP
-        :param second_rbp: the second RBP, or -1 if you need against all
-                  (Default value = -1)
-        :param display_threshold:  the cutoff value below which correlation
-                                   pairs should not be shown
-                                   (Default value = -0.1)
-        :param bp_threshold:  the number of bases beyond which two RBPs are
-                              considered too far in terms of the distance
-                              between a pair of their binding sites
-                              (Default value = 30)
-
-        """
-        if self.corr_table == -1 or self.corr_bp_threshold != bp_threshold:
-            self.self_analysis(
-                bp_threshold=bp_threshold, display_threshold=1.1
-            )
-
-        if second_rbp == -1:
-            to_return_list = []
-            corr_entries = self.corr_table_f_measure.get(first_rbp, {})
-            for key in sorted(
-                corr_entries, key=corr_entries.get, reverse=True
-            ):
-                if float(corr_entries[key]) > display_threshold:
-                    to_return_list.append((key, corr_entries[key]))
-
-            return to_return_list
-
-        return self.corr_table_f_measure.get(first_rbp, {}).get(second_rbp, 0)
-
-    def lookup_table(self):
-        """
-        Returns the correlation table for this RNA molecule.
-        A correlation table describes the extent to which the RBPs binding to
-        this molecule have similar binding patterns on this RNA.
-        """
         return self.corr_table_f_measure
 
     def binds_near(self, interval_range, bp_threshold=30):
         """
         This function takes a tuple representing an interval that one wants
-        to test on the lncRNA and returns a Storage of RBPs binding to or near
+        to test on the lncRNA and returns a list of RBPs binding to or near
         that interval
 
         :param interval_range: in the form (start, end) or (start, end, _)
@@ -365,11 +291,11 @@ class Storage:
         start, end, *_ = interval_range
         extended_range = (start - bp_threshold, end + bp_threshold)
 
-        to_return = Storage()
+        to_return = []
 
-        for k in self._rbps:
-            if self._rbps[k].is_overlap(extended_range):
-                to_return[k] = self._rbps[k]
+        for rbp, sites in self._rbps.items():
+            if sites.is_overlap(extended_range):
+                to_return.append(rbp)
 
         return to_return
 
@@ -384,9 +310,9 @@ class Storage:
 
         """
         to_return = Storage()
-        for k in self._rbps:
-            if filter_func(k):
-                to_return[k] = self._rbps[k]
+        for rbp, sites in self._rbps.items():
+            if filter_func(rbp):
+                to_return[rbp] = sites
 
         return to_return
 
@@ -419,6 +345,7 @@ class Storage:
         }
 
         """
+        gene = gene.upper()
         # sanity check
         if gene not in self._rbps:
             gene = self.synonym_func(gene)
@@ -440,12 +367,6 @@ class Storage:
         """
         print(self)
 
-    def len(self):
-        """
-        returns the number of RBPs binding to this Storage (RNA) instance
-        """
-        return len(self)
-
     def all_sites_in(self, interval_range, bp_threshold=0):
         """
         returns a new Storage instance only containing binding sites contained
@@ -572,6 +493,12 @@ class Storage:
         for rbp in self:
             for site in self[rbp]:
                 # print(site)
+                start, end, annotation = site
+                if annotation:
+                    annotation += rbp
+                else:
+                    annotation = rbp
+                site = (start, end, annotation)
                 new_binding_site.add(site)
         return new_binding_site
 
@@ -584,6 +511,8 @@ class Storage:
         name="",
         description="",
         include_header=True,
+        antisense=False,
+        length=-1,
     ):
         """
         Prints a WIG file represeting the density of binding by the RBPs on the
@@ -598,6 +527,8 @@ class Storage:
         :param name:  (Default value = "")
         :param description:  (Default value = "")
         :param include_header:  (Default value = True)
+        :param antisense:  (Default value = False)
+        :param length:  (Default value = -1)
 
         """
 
@@ -609,4 +540,6 @@ class Storage:
             name=name,
             description=description,
             include_header=include_header,
+            antisense=antisense,
+            length=length,
         )
