@@ -33,6 +33,11 @@ OVERLAP_CONFLICT = "union"
 # with "None" instead
 
 
+class NoSites(Exception):
+    """Raised when there are no sites in the BindingSite but a site is
+    sought"""
+
+
 class BindingSites:
     """
     BindingSites allows adding binding sites, removing binding sites, querying
@@ -154,7 +159,7 @@ class BindingSites:
 
         start_1, end_1, *_ = interval_1
         start_2, end_2, *_ = interval_2
-        return start_1 <= end_2 and start_2 <= end_1
+        return start_1 < end_2 and start_2 < end_1
 
     @staticmethod
     def _merge_meta(annotation_list, user_merge_func=None):
@@ -205,8 +210,11 @@ class BindingSites:
         return new_l_set.pop()
 
     @staticmethod
-    def _collapse(interval_list, user_merge_func=None):
-        """Takes a list of overlapping ranges and collapses them into one
+    def _collapse(interval_list: "BindingSites", user_merge_func=None):
+        """Takes a list of overlapping ranges and collapses them into one.
+
+        A precondition is that the ranges are overlapping overall (even with
+        chained relations)
 
         :param interval_list: A list of intervals to be merged
         :param user_merge_func: if specified, this function is used to merge the
@@ -336,6 +344,9 @@ class BindingSites:
 
         """
 
+        # If the threshold is lower than one it's the same as being one
+        bp_threshold = max(1, bp_threshold)
+
         if self.overlap_mode:
             raise ValueError(
                 "dist() is not supported for BindingSites with"
@@ -413,7 +424,8 @@ class BindingSites:
 
     def nearest_site(self, query_site):
         """This returns the closest range to the input tuple range
-        present in the set of binding sites stored in self
+        present in the set of binding sites stored in self, as well as the
+        distance to said site.
 
         :param query_site: a site in the form (start, end, metadata) or just
                             (start, end)
@@ -429,6 +441,9 @@ class BindingSites:
         start, end, *_ = query_site
         pos = self.sorted_sites.bisect_left((start, 0))
 
+        if not self.sorted_sites:
+            raise NoSites
+
         # tuple at the beginning
         if pos == 0:
             dist_end = self.sorted_sites[pos][0] - end
@@ -467,12 +482,6 @@ class BindingSites:
         start_2, end_2, *_ = site_2
         return min(abs(start_1 - end_2), abs(start_2 - end_1))
 
-    def print(self):
-        """
-        prints the BindingSite instance
-        """
-        print(self)
-
     def len(self):
         """
         returns the number of sites stored in the BindingSite instance
@@ -563,7 +572,10 @@ class BindingSites:
         else:
             chr_n = ("chr" + chr_n) if chr_n[:3] != "chr" else chr_n
 
-        for _tuple in self.sorted_sites:
+        sorted_sites = (
+            self.sorted_sites if not antisense else reversed(self.sorted_sites)
+        )
+        for _tuple in sorted_sites:
             start, end, annotation = _tuple
             if antisense:
                 start, end = -end, -start
@@ -642,7 +654,7 @@ class BindingSites:
                     " do not call return_depth without "
                     "specifying the length parameter."
                 )
-            length = max(map(secondItem, self)) + 1
+            length = max(map(secondItem, self))
 
         # Stores 'depth' of support for each nucleotide in the
         # molecule in terms of its chances of being a binding site.
@@ -653,7 +665,9 @@ class BindingSites:
             start = site[0]
             end = site[1]
 
-            for nucleotide in range(start, end + 1):  # inclusive
+            # TODO: Document coordinate system choice and remain consistent
+            # start inclusive, end exclusive
+            for nucleotide in range(start, end):
                 binding_depth[nucleotide] += 1
 
         return binding_depth
@@ -674,9 +688,9 @@ class BindingSites:
         'TopDepthNumber', 'MinimumDepthNumber', 'TopSitesNumber','TopSitesRatio'
 
             'baseCoverNumber': Choose cut off based on maximum number of bases
-                that the selected sites are allowed to cover. The most stringent
-                depth cutoff that achieves this criteria is selected, unless not
-                possible*.
+                that the selected sites are allowed to cover (laterally). The
+                most stringent depth cutoff that achieves this criteria is
+                selected, unless not possible*.
 
             'TopDepthRatio': Choose cutoff based on the fraction of highest
                 depth coverage that should be supported as binding sites. For
@@ -705,8 +719,8 @@ class BindingSites:
         associated with the original range interval data.
 
         If inPlace is set to True, the BindingSites variable changes and
-        collpases, otherwise a new BindingSites variable is generated and
-        returned.
+        collpases (None is returned), otherwise a new BindingSites variable is
+        generated and returned.
 
         *In general, no nucleotide with support<1 is kept.
 
@@ -788,28 +802,30 @@ class BindingSites:
                     in_range = True
             else:
                 if in_range:
-                    end_range = nucleotide - 1
+                    end_range = nucleotide
                     in_range = False
                     binding_site_to_add_to.add((start_range, end_range))
 
         if in_range:
-            end_range = nucleotide
+            end_range = nucleotide + 1
             in_range = False
             binding_site_to_add_to.add((start_range, end_range))
 
-        # Add annotations
-        for site in sites:
-            start, end, annotation = site
-            # print(start, end, annotation)
-            site, distance = binding_site_to_add_to.nearest_site(site)
-            if distance == 0:
-                binding_site_to_add_to.add(
-                    (start, end, annotation), annotation_merger
-                )
+        if len(binding_site_to_add_to) > 0:
+            # Add annotations
+            for site in sites:
+                _, _, annotation = site
+                site, distance = binding_site_to_add_to.nearest_site(site)
+                start, end, _ = site
+                if distance == 0:
+                    binding_site_to_add_to.add(
+                        (start, end, annotation), annotation_merger
+                    )
+
         if not in_place:
             return binding_site_to_add_to
 
-        return BindingSites()
+        return None
 
     def base_cover(self):
         """
@@ -832,6 +848,7 @@ class BindingSites:
         description="",
         include_header=True,
         length=-1,
+        antisense=False,
     ):
         """Prints a wig file depicting density of binding sites by the RBP.
 
@@ -846,6 +863,7 @@ class BindingSites:
         :param description:  (Default value = "")
         :param include_header:  (Default value = True)
         :param length:  (Default value = -1)
+        :param antisense:  (Default value = False)
 
         """
 
@@ -873,6 +891,8 @@ class BindingSites:
 
         # length long array, 0-indexed
         depth_array = self.return_depth(length=length)
+        if antisense:
+            depth_array = reversed(depth_array)
         output_str += "\n".join(map(str, depth_array))
 
         return output_str
