@@ -35,11 +35,15 @@ def populate_binding_sites(
 
     rna_chr_no = rna_info["chr_n"]
     rna_start_chr_coord = rna_info["start_coord"]
+    rna_end_chr_coord = rna_info["end_coord"]
+    strand = rna_info["strand"]
 
     # The RNA start coordinate is 1-based. But all BED file binding sites
     # should be half-open and 0-based, and the binding sites returned by
     # data loading functions are half-open and 0-based.
-    displacement = rna_start_chr_coord - 1
+    displacement = (
+        rna_start_chr_coord - 1 if strand == "+" else rna_end_chr_coord
+    )
 
     comp_color = red
     coop_color = green
@@ -60,20 +64,6 @@ def populate_binding_sites(
                 f"Directory {folder_path} already exists...", file=sys.stderr
             )
 
-        # with open(
-        #     Path(overarching_path) / "threshold_config.txt", "w"
-        # ) as threshold_config_file:
-        #     threshold_config_file.write(
-        #         "competitive threshold used: "
-        #         + str(competitive_threshold_bp)
-        #         + "\n"
-        #     )
-        #     threshold_config_file.write(
-        #         "cooperative threshold used: "
-        #         + str(cooperative_threshold_bp)
-        #         + "\n"
-        #     )
-
         default_color = data_load_source_colors[data_load_source]
 
         def coloring_func(
@@ -109,7 +99,8 @@ def populate_binding_sites(
             total_sites = storage[[rbp]].print_bed(
                 chr_n=rna_chr_no,
                 displacement=displacement,
-                end_inclusion=False, # BED files have to be 0-based, half-open.
+                antisense=strand == "-",
+                end_inclusion=False,  # BED files have to be 0-based, half-open.
                 add_annotation=True,
                 include_color=True,
                 include_header=False,
